@@ -15,9 +15,14 @@ from .config.extras.gql import GQL
 # from .graphql import BaseType
 from .schema import Schema
 from .types import Model, SQLFilters
-from .config.commands.graphql import to_camel_case
 
 # Custom Field Types
 Text = Model.text
 JSON = Model.json
-ID = strawberry.ID
\ No newline at end of file
+ID = strawberry.ID
+
+# To Camel Case
+def to_camel_case(text):
+    """Converts to Camel-Case"""
+    init, *temp = text.split("_")
+    return "".join([init.lower(), *map(str.title, temp)])
